[![bobrossquotes](https://snapcraft.io/bobrossquotes/badge.svg)](https://snapcraft.io/bobrossquotes)

# BobRossQuotes


A collection of quotes from Bob Ross. 

## To install:

`sudo snap install bobrossquotes`

## To run:

From your terminal: `bobrossquotes`

## Star History

[![Star History Chart](https://api.star-history.com/svg?repos=kz6fittycent/BobRossQuotes&type=Date)](https://star-history.com/#kz6fittycent/BobRossQuotes&Date)
